@@ -3,6 +3,7 @@ import hackingtools as ht
 
 from PIL import Image
 from PyPDF2 import PdfFileReader, PdfFileWriter
+import pdfrw
 from pdfrw import PdfReader, PdfWriter 
 # import mutagen
 
@@ -40,8 +41,9 @@ class StartModule():
 				pdf = PdfFileReader(f)
 				info = pdf.getDocumentInfo()
 				number_of_pages = pdf.getNumPages()
-			for a in info:
-				data[a] = info[a]
+			if info:
+				for a in info:
+					data[a] = info[a]
 			return data
 		except Exception as e:
 			Logger.printMessage(message='{methodName}'.format(methodName='exception'), description=e, debug_module=True)
@@ -50,7 +52,9 @@ class StartModule():
 	
 	def set_pdf_field_value(self, pdf_file, field, fieldValue):
 		try:
-			trailer = PdfReader(pdf_file)    
+			trailer = PdfReader(pdf_file)
+			if trailer.Info is None:
+				trailer.Info = pdfrw.objects.pdfdict.PdfDict()
 			setDataQuery = 'trailer.Info.{f} = "{v}"'.format(f=field.replace('/', ''), v=fieldValue)
 			exec(setDataQuery)
 			new_pdf = os.path.split(pdf_file)[1]
